/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.ec2.model;

import java.io.Serializable;

/**
 * <p>
 * Contains the output of DescribeSecurityGroups.
 * </p>
 */
public class DescribeSecurityGroupsResult implements Serializable, Cloneable {

    /**
     * <p>
     * Information about one or more security groups.
     * </p>
     */
    private com.amazonaws.internal.SdkInternalList<SecurityGroup> securityGroups;

    /**
     * <p>
     * Information about one or more security groups.
     * </p>
     * 
     * @return Information about one or more security groups.
     */

    public java.util.List<SecurityGroup> getSecurityGroups() {
        if (securityGroups == null) {
            securityGroups = new com.amazonaws.internal.SdkInternalList<SecurityGroup>();
        }
        return securityGroups;
    }

    /**
     * <p>
     * Information about one or more security groups.
     * </p>
     * 
     * @param securityGroups
     *        Information about one or more security groups.
     */

    public void setSecurityGroups(
            java.util.Collection<SecurityGroup> securityGroups) {
        if (securityGroups == null) {
            this.securityGroups = null;
            return;
        }

        this.securityGroups = new com.amazonaws.internal.SdkInternalList<SecurityGroup>(
                securityGroups);
    }

    /**
     * <p>
     * Information about one or more security groups.
     * </p>
     * <p>
     * <b>NOTE:</b> This method appends the values to the existing list (if
     * any). Use {@link #setSecurityGroups(java.util.Collection)} or
     * {@link #withSecurityGroups(java.util.Collection)} if you want to override
     * the existing values.
     * </p>
     * 
     * @param securityGroups
     *        Information about one or more security groups.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public DescribeSecurityGroupsResult withSecurityGroups(
            SecurityGroup... securityGroups) {
        if (this.securityGroups == null) {
            setSecurityGroups(new com.amazonaws.internal.SdkInternalList<SecurityGroup>(
                    securityGroups.length));
        }
        for (SecurityGroup ele : securityGroups) {
            this.securityGroups.add(ele);
        }
        return this;
    }

    /**
     * <p>
     * Information about one or more security groups.
     * </p>
     * 
     * @param securityGroups
     *        Information about one or more security groups.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public DescribeSecurityGroupsResult withSecurityGroups(
            java.util.Collection<SecurityGroup> securityGroups) {
        setSecurityGroups(securityGroups);
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getSecurityGroups() != null)
            sb.append("SecurityGroups: " + getSecurityGroups());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof DescribeSecurityGroupsResult == false)
            return false;
        DescribeSecurityGroupsResult other = (DescribeSecurityGroupsResult) obj;
        if (other.getSecurityGroups() == null
                ^ this.getSecurityGroups() == null)
            return false;
        if (other.getSecurityGroups() != null
                && other.getSecurityGroups().equals(this.getSecurityGroups()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime
                * hashCode
                + ((getSecurityGroups() == null) ? 0 : getSecurityGroups()
                        .hashCode());
        return hashCode;
    }

    @Override
    public DescribeSecurityGroupsResult clone() {
        try {
            return (DescribeSecurityGroupsResult) super.clone();
        } catch (CloneNotSupportedException e) {
            throw new IllegalStateException(
                    "Got a CloneNotSupportedException from Object.clone() "
                            + "even though we're Cloneable!", e);
        }
    }
}