/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.gamelift.model;

import java.io.Serializable;

/**
 * <p>
 * Information about the fleet's capacity. Fleet capacity is measured in EC2
 * instances. By default, new fleets have a capacity of one instance, but can be
 * updated as needed. The maximum number of instances for a fleet is determined
 * by the fleet's instance type.
 * </p>
 */
public class FleetCapacity implements Serializable, Cloneable {

    /**
     * <p>
     * Unique identifier for a fleet.
     * </p>
     */
    private String fleetId;
    /**
     * <p>
     * Type of EC2 instances used in the fleet. EC2 instance types define the
     * CPU, memory, storage, and networking capacity of the fleetaposs hosts.
     * Amazon GameLift supports the EC2 instance types listed below. See <a
     * href="https://aws.amazon.com/ec2/instance-types/">Amazon EC2 Instance
     * Types</a> for detailed descriptions of each.
     * </p>
     */
    private String instanceType;
    /**
     * <p>
     * Current status of fleet capacity.
     * </p>
     */
    private EC2InstanceCounts instanceCounts;

    /**
     * <p>
     * Unique identifier for a fleet.
     * </p>
     * 
     * @param fleetId
     *        Unique identifier for a fleet.
     */

    public void setFleetId(String fleetId) {
        this.fleetId = fleetId;
    }

    /**
     * <p>
     * Unique identifier for a fleet.
     * </p>
     * 
     * @return Unique identifier for a fleet.
     */

    public String getFleetId() {
        return this.fleetId;
    }

    /**
     * <p>
     * Unique identifier for a fleet.
     * </p>
     * 
     * @param fleetId
     *        Unique identifier for a fleet.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public FleetCapacity withFleetId(String fleetId) {
        setFleetId(fleetId);
        return this;
    }

    /**
     * <p>
     * Type of EC2 instances used in the fleet. EC2 instance types define the
     * CPU, memory, storage, and networking capacity of the fleetaposs hosts.
     * Amazon GameLift supports the EC2 instance types listed below. See <a
     * href="https://aws.amazon.com/ec2/instance-types/">Amazon EC2 Instance
     * Types</a> for detailed descriptions of each.
     * </p>
     * 
     * @param instanceType
     *        Type of EC2 instances used in the fleet. EC2 instance types define
     *        the CPU, memory, storage, and networking capacity of the
     *        fleetaposs hosts. Amazon GameLift supports the EC2 instance types
     *        listed below. See <a
     *        href="https://aws.amazon.com/ec2/instance-types/">Amazon EC2
     *        Instance Types</a> for detailed descriptions of each.
     * @see EC2InstanceType
     */

    public void setInstanceType(String instanceType) {
        this.instanceType = instanceType;
    }

    /**
     * <p>
     * Type of EC2 instances used in the fleet. EC2 instance types define the
     * CPU, memory, storage, and networking capacity of the fleetaposs hosts.
     * Amazon GameLift supports the EC2 instance types listed below. See <a
     * href="https://aws.amazon.com/ec2/instance-types/">Amazon EC2 Instance
     * Types</a> for detailed descriptions of each.
     * </p>
     * 
     * @return Type of EC2 instances used in the fleet. EC2 instance types
     *         define the CPU, memory, storage, and networking capacity of the
     *         fleetaposs hosts. Amazon GameLift supports the EC2 instance types
     *         listed below. See <a
     *         href="https://aws.amazon.com/ec2/instance-types/">Amazon EC2
     *         Instance Types</a> for detailed descriptions of each.
     * @see EC2InstanceType
     */

    public String getInstanceType() {
        return this.instanceType;
    }

    /**
     * <p>
     * Type of EC2 instances used in the fleet. EC2 instance types define the
     * CPU, memory, storage, and networking capacity of the fleetaposs hosts.
     * Amazon GameLift supports the EC2 instance types listed below. See <a
     * href="https://aws.amazon.com/ec2/instance-types/">Amazon EC2 Instance
     * Types</a> for detailed descriptions of each.
     * </p>
     * 
     * @param instanceType
     *        Type of EC2 instances used in the fleet. EC2 instance types define
     *        the CPU, memory, storage, and networking capacity of the
     *        fleetaposs hosts. Amazon GameLift supports the EC2 instance types
     *        listed below. See <a
     *        href="https://aws.amazon.com/ec2/instance-types/">Amazon EC2
     *        Instance Types</a> for detailed descriptions of each.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     * @see EC2InstanceType
     */

    public FleetCapacity withInstanceType(String instanceType) {
        setInstanceType(instanceType);
        return this;
    }

    /**
     * <p>
     * Type of EC2 instances used in the fleet. EC2 instance types define the
     * CPU, memory, storage, and networking capacity of the fleetaposs hosts.
     * Amazon GameLift supports the EC2 instance types listed below. See <a
     * href="https://aws.amazon.com/ec2/instance-types/">Amazon EC2 Instance
     * Types</a> for detailed descriptions of each.
     * </p>
     * 
     * @param instanceType
     *        Type of EC2 instances used in the fleet. EC2 instance types define
     *        the CPU, memory, storage, and networking capacity of the
     *        fleetaposs hosts. Amazon GameLift supports the EC2 instance types
     *        listed below. See <a
     *        href="https://aws.amazon.com/ec2/instance-types/">Amazon EC2
     *        Instance Types</a> for detailed descriptions of each.
     * @see EC2InstanceType
     */

    public void setInstanceType(EC2InstanceType instanceType) {
        this.instanceType = instanceType.toString();
    }

    /**
     * <p>
     * Type of EC2 instances used in the fleet. EC2 instance types define the
     * CPU, memory, storage, and networking capacity of the fleetaposs hosts.
     * Amazon GameLift supports the EC2 instance types listed below. See <a
     * href="https://aws.amazon.com/ec2/instance-types/">Amazon EC2 Instance
     * Types</a> for detailed descriptions of each.
     * </p>
     * 
     * @param instanceType
     *        Type of EC2 instances used in the fleet. EC2 instance types define
     *        the CPU, memory, storage, and networking capacity of the
     *        fleetaposs hosts. Amazon GameLift supports the EC2 instance types
     *        listed below. See <a
     *        href="https://aws.amazon.com/ec2/instance-types/">Amazon EC2
     *        Instance Types</a> for detailed descriptions of each.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     * @see EC2InstanceType
     */

    public FleetCapacity withInstanceType(EC2InstanceType instanceType) {
        setInstanceType(instanceType);
        return this;
    }

    /**
     * <p>
     * Current status of fleet capacity.
     * </p>
     * 
     * @param instanceCounts
     *        Current status of fleet capacity.
     */

    public void setInstanceCounts(EC2InstanceCounts instanceCounts) {
        this.instanceCounts = instanceCounts;
    }

    /**
     * <p>
     * Current status of fleet capacity.
     * </p>
     * 
     * @return Current status of fleet capacity.
     */

    public EC2InstanceCounts getInstanceCounts() {
        return this.instanceCounts;
    }

    /**
     * <p>
     * Current status of fleet capacity.
     * </p>
     * 
     * @param instanceCounts
     *        Current status of fleet capacity.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public FleetCapacity withInstanceCounts(EC2InstanceCounts instanceCounts) {
        setInstanceCounts(instanceCounts);
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getFleetId() != null)
            sb.append("FleetId: " + getFleetId() + ",");
        if (getInstanceType() != null)
            sb.append("InstanceType: " + getInstanceType() + ",");
        if (getInstanceCounts() != null)
            sb.append("InstanceCounts: " + getInstanceCounts());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof FleetCapacity == false)
            return false;
        FleetCapacity other = (FleetCapacity) obj;
        if (other.getFleetId() == null ^ this.getFleetId() == null)
            return false;
        if (other.getFleetId() != null
                && other.getFleetId().equals(this.getFleetId()) == false)
            return false;
        if (other.getInstanceType() == null ^ this.getInstanceType() == null)
            return false;
        if (other.getInstanceType() != null
                && other.getInstanceType().equals(this.getInstanceType()) == false)
            return false;
        if (other.getInstanceCounts() == null
                ^ this.getInstanceCounts() == null)
            return false;
        if (other.getInstanceCounts() != null
                && other.getInstanceCounts().equals(this.getInstanceCounts()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime * hashCode
                + ((getFleetId() == null) ? 0 : getFleetId().hashCode());
        hashCode = prime
                * hashCode
                + ((getInstanceType() == null) ? 0 : getInstanceType()
                        .hashCode());
        hashCode = prime
                * hashCode
                + ((getInstanceCounts() == null) ? 0 : getInstanceCounts()
                        .hashCode());
        return hashCode;
    }

    @Override
    public FleetCapacity clone() {
        try {
            return (FleetCapacity) super.clone();
        } catch (CloneNotSupportedException e) {
            throw new IllegalStateException(
                    "Got a CloneNotSupportedException from Object.clone() "
                            + "even though we're Cloneable!", e);
        }
    }
}
