/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.route53.model;

/**
 * 
 */
public enum ComparisonOperator {

    GreaterThanOrEqualToThreshold("GreaterThanOrEqualToThreshold"),
    GreaterThanThreshold("GreaterThanThreshold"),
    LessThanThreshold("LessThanThreshold"),
    LessThanOrEqualToThreshold("LessThanOrEqualToThreshold");

    private String value;

    private ComparisonOperator(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value
     *        real value
     * @return ComparisonOperator corresponding to the value
     */
    public static ComparisonOperator fromValue(String value) {
        if (value == null || "".equals(value)) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        } else if ("GreaterThanOrEqualToThreshold".equals(value)) {
            return GreaterThanOrEqualToThreshold;
        } else if ("GreaterThanThreshold".equals(value)) {
            return GreaterThanThreshold;
        } else if ("LessThanThreshold".equals(value)) {
            return LessThanThreshold;
        } else if ("LessThanOrEqualToThreshold".equals(value)) {
            return LessThanOrEqualToThreshold;
        } else {
            throw new IllegalArgumentException("Cannot create enum from "
                    + value + " value!");
        }
    }
}