/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.simpleworkflow.model;

import java.io.Serializable;

/**
 * <p>
 * Provides details of the <code>WorkflowExecutionTimedOut</code> event.
 * </p>
 */
public class WorkflowExecutionTimedOutEventAttributes implements Serializable,
        Cloneable {

    /**
     * <p>
     * The type of timeout that caused this event.
     * </p>
     */
    private String timeoutType;
    /**
     * <p>
     * The policy used for the child workflow executions of this workflow
     * execution.
     * </p>
     * <p>
     * The supported child policies are:
     * </p>
     * <ul>
     * <li><b>TERMINATE:</b> the child executions will be terminated.</li>
     * <li><b>REQUEST_CANCEL:</b> a request to cancel will be attempted for each
     * child execution by recording a
     * <code>WorkflowExecutionCancelRequested</code> event in its history. It is
     * up to the decider to take appropriate actions when it receives an
     * execution history with this event.</li>
     * <li><b>ABANDON:</b> no action will be taken. The child executions will
     * continue to run.</li>
     * </ul>
     */
    private String childPolicy;

    /**
     * <p>
     * The type of timeout that caused this event.
     * </p>
     * 
     * @param timeoutType
     *        The type of timeout that caused this event.
     * @see WorkflowExecutionTimeoutType
     */

    public void setTimeoutType(String timeoutType) {
        this.timeoutType = timeoutType;
    }

    /**
     * <p>
     * The type of timeout that caused this event.
     * </p>
     * 
     * @return The type of timeout that caused this event.
     * @see WorkflowExecutionTimeoutType
     */

    public String getTimeoutType() {
        return this.timeoutType;
    }

    /**
     * <p>
     * The type of timeout that caused this event.
     * </p>
     * 
     * @param timeoutType
     *        The type of timeout that caused this event.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     * @see WorkflowExecutionTimeoutType
     */

    public WorkflowExecutionTimedOutEventAttributes withTimeoutType(
            String timeoutType) {
        setTimeoutType(timeoutType);
        return this;
    }

    /**
     * <p>
     * The type of timeout that caused this event.
     * </p>
     * 
     * @param timeoutType
     *        The type of timeout that caused this event.
     * @see WorkflowExecutionTimeoutType
     */

    public void setTimeoutType(WorkflowExecutionTimeoutType timeoutType) {
        this.timeoutType = timeoutType.toString();
    }

    /**
     * <p>
     * The type of timeout that caused this event.
     * </p>
     * 
     * @param timeoutType
     *        The type of timeout that caused this event.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     * @see WorkflowExecutionTimeoutType
     */

    public WorkflowExecutionTimedOutEventAttributes withTimeoutType(
            WorkflowExecutionTimeoutType timeoutType) {
        setTimeoutType(timeoutType);
        return this;
    }

    /**
     * <p>
     * The policy used for the child workflow executions of this workflow
     * execution.
     * </p>
     * <p>
     * The supported child policies are:
     * </p>
     * <ul>
     * <li><b>TERMINATE:</b> the child executions will be terminated.</li>
     * <li><b>REQUEST_CANCEL:</b> a request to cancel will be attempted for each
     * child execution by recording a
     * <code>WorkflowExecutionCancelRequested</code> event in its history. It is
     * up to the decider to take appropriate actions when it receives an
     * execution history with this event.</li>
     * <li><b>ABANDON:</b> no action will be taken. The child executions will
     * continue to run.</li>
     * </ul>
     * 
     * @param childPolicy
     *        The policy used for the child workflow executions of this workflow
     *        execution.</p>
     *        <p>
     *        The supported child policies are:
     *        </p>
     *        <ul>
     *        <li><b>TERMINATE:</b> the child executions will be terminated.</li>
     *        <li><b>REQUEST_CANCEL:</b> a request to cancel will be attempted
     *        for each child execution by recording a
     *        <code>WorkflowExecutionCancelRequested</code> event in its
     *        history. It is up to the decider to take appropriate actions when
     *        it receives an execution history with this event.</li>
     *        <li><b>ABANDON:</b> no action will be taken. The child executions
     *        will continue to run.</li>
     * @see ChildPolicy
     */

    public void setChildPolicy(String childPolicy) {
        this.childPolicy = childPolicy;
    }

    /**
     * <p>
     * The policy used for the child workflow executions of this workflow
     * execution.
     * </p>
     * <p>
     * The supported child policies are:
     * </p>
     * <ul>
     * <li><b>TERMINATE:</b> the child executions will be terminated.</li>
     * <li><b>REQUEST_CANCEL:</b> a request to cancel will be attempted for each
     * child execution by recording a
     * <code>WorkflowExecutionCancelRequested</code> event in its history. It is
     * up to the decider to take appropriate actions when it receives an
     * execution history with this event.</li>
     * <li><b>ABANDON:</b> no action will be taken. The child executions will
     * continue to run.</li>
     * </ul>
     * 
     * @return The policy used for the child workflow executions of this
     *         workflow execution.</p>
     *         <p>
     *         The supported child policies are:
     *         </p>
     *         <ul>
     *         <li><b>TERMINATE:</b> the child executions will be terminated.</li>
     *         <li><b>REQUEST_CANCEL:</b> a request to cancel will be attempted
     *         for each child execution by recording a
     *         <code>WorkflowExecutionCancelRequested</code> event in its
     *         history. It is up to the decider to take appropriate actions when
     *         it receives an execution history with this event.</li>
     *         <li><b>ABANDON:</b> no action will be taken. The child executions
     *         will continue to run.</li>
     * @see ChildPolicy
     */

    public String getChildPolicy() {
        return this.childPolicy;
    }

    /**
     * <p>
     * The policy used for the child workflow executions of this workflow
     * execution.
     * </p>
     * <p>
     * The supported child policies are:
     * </p>
     * <ul>
     * <li><b>TERMINATE:</b> the child executions will be terminated.</li>
     * <li><b>REQUEST_CANCEL:</b> a request to cancel will be attempted for each
     * child execution by recording a
     * <code>WorkflowExecutionCancelRequested</code> event in its history. It is
     * up to the decider to take appropriate actions when it receives an
     * execution history with this event.</li>
     * <li><b>ABANDON:</b> no action will be taken. The child executions will
     * continue to run.</li>
     * </ul>
     * 
     * @param childPolicy
     *        The policy used for the child workflow executions of this workflow
     *        execution.</p>
     *        <p>
     *        The supported child policies are:
     *        </p>
     *        <ul>
     *        <li><b>TERMINATE:</b> the child executions will be terminated.</li>
     *        <li><b>REQUEST_CANCEL:</b> a request to cancel will be attempted
     *        for each child execution by recording a
     *        <code>WorkflowExecutionCancelRequested</code> event in its
     *        history. It is up to the decider to take appropriate actions when
     *        it receives an execution history with this event.</li>
     *        <li><b>ABANDON:</b> no action will be taken. The child executions
     *        will continue to run.</li>
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     * @see ChildPolicy
     */

    public WorkflowExecutionTimedOutEventAttributes withChildPolicy(
            String childPolicy) {
        setChildPolicy(childPolicy);
        return this;
    }

    /**
     * <p>
     * The policy used for the child workflow executions of this workflow
     * execution.
     * </p>
     * <p>
     * The supported child policies are:
     * </p>
     * <ul>
     * <li><b>TERMINATE:</b> the child executions will be terminated.</li>
     * <li><b>REQUEST_CANCEL:</b> a request to cancel will be attempted for each
     * child execution by recording a
     * <code>WorkflowExecutionCancelRequested</code> event in its history. It is
     * up to the decider to take appropriate actions when it receives an
     * execution history with this event.</li>
     * <li><b>ABANDON:</b> no action will be taken. The child executions will
     * continue to run.</li>
     * </ul>
     * 
     * @param childPolicy
     *        The policy used for the child workflow executions of this workflow
     *        execution.</p>
     *        <p>
     *        The supported child policies are:
     *        </p>
     *        <ul>
     *        <li><b>TERMINATE:</b> the child executions will be terminated.</li>
     *        <li><b>REQUEST_CANCEL:</b> a request to cancel will be attempted
     *        for each child execution by recording a
     *        <code>WorkflowExecutionCancelRequested</code> event in its
     *        history. It is up to the decider to take appropriate actions when
     *        it receives an execution history with this event.</li>
     *        <li><b>ABANDON:</b> no action will be taken. The child executions
     *        will continue to run.</li>
     * @see ChildPolicy
     */

    public void setChildPolicy(ChildPolicy childPolicy) {
        this.childPolicy = childPolicy.toString();
    }

    /**
     * <p>
     * The policy used for the child workflow executions of this workflow
     * execution.
     * </p>
     * <p>
     * The supported child policies are:
     * </p>
     * <ul>
     * <li><b>TERMINATE:</b> the child executions will be terminated.</li>
     * <li><b>REQUEST_CANCEL:</b> a request to cancel will be attempted for each
     * child execution by recording a
     * <code>WorkflowExecutionCancelRequested</code> event in its history. It is
     * up to the decider to take appropriate actions when it receives an
     * execution history with this event.</li>
     * <li><b>ABANDON:</b> no action will be taken. The child executions will
     * continue to run.</li>
     * </ul>
     * 
     * @param childPolicy
     *        The policy used for the child workflow executions of this workflow
     *        execution.</p>
     *        <p>
     *        The supported child policies are:
     *        </p>
     *        <ul>
     *        <li><b>TERMINATE:</b> the child executions will be terminated.</li>
     *        <li><b>REQUEST_CANCEL:</b> a request to cancel will be attempted
     *        for each child execution by recording a
     *        <code>WorkflowExecutionCancelRequested</code> event in its
     *        history. It is up to the decider to take appropriate actions when
     *        it receives an execution history with this event.</li>
     *        <li><b>ABANDON:</b> no action will be taken. The child executions
     *        will continue to run.</li>
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     * @see ChildPolicy
     */

    public WorkflowExecutionTimedOutEventAttributes withChildPolicy(
            ChildPolicy childPolicy) {
        setChildPolicy(childPolicy);
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getTimeoutType() != null)
            sb.append("TimeoutType: " + getTimeoutType() + ",");
        if (getChildPolicy() != null)
            sb.append("ChildPolicy: " + getChildPolicy());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof WorkflowExecutionTimedOutEventAttributes == false)
            return false;
        WorkflowExecutionTimedOutEventAttributes other = (WorkflowExecutionTimedOutEventAttributes) obj;
        if (other.getTimeoutType() == null ^ this.getTimeoutType() == null)
            return false;
        if (other.getTimeoutType() != null
                && other.getTimeoutType().equals(this.getTimeoutType()) == false)
            return false;
        if (other.getChildPolicy() == null ^ this.getChildPolicy() == null)
            return false;
        if (other.getChildPolicy() != null
                && other.getChildPolicy().equals(this.getChildPolicy()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime
                * hashCode
                + ((getTimeoutType() == null) ? 0 : getTimeoutType().hashCode());
        hashCode = prime
                * hashCode
                + ((getChildPolicy() == null) ? 0 : getChildPolicy().hashCode());
        return hashCode;
    }

    @Override
    public WorkflowExecutionTimedOutEventAttributes clone() {
        try {
            return (WorkflowExecutionTimedOutEventAttributes) super.clone();
        } catch (CloneNotSupportedException e) {
            throw new IllegalStateException(
                    "Got a CloneNotSupportedException from Object.clone() "
                            + "even though we're Cloneable!", e);
        }
    }
}
